@charset "UTF-8";
/*!
 * @copyright   (C) 2017 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
.checkbox-toggle {
  display: none !important;
}

.checkbox-toggle[disabled] ~ .btn-hide {
  opacity: .5;
}

.checkbox-toggle ~ .btn-show {
  display: inline;
}

.checkbox-toggle ~ .btn-hide, .checkbox-toggle:checked ~ .btn-show {
  display: none;
}

.checkbox-toggle:checked ~ .btn-hide {
  display: inline;
}
