@charset "UTF-8";
:where(.mod-menu__toggle-sub) {
  color: currentColor;
  background-color: #0000;
  border: none;
  align-items: center;
  padding: 0;
  display: inline-flex;

  &[aria-expanded="true"] .icon-chevron-down {
    transform: rotate(180deg);
  }
}

:where(.mod-menu [class*="icon-"]) {
  margin-inline-start: .5rem;
  transition: all .2s, background-color .2s;
}

:where(.mod-menu__sub[aria-hidden="true"]) {
  display: none;
}

:where(.mod-menu__sub[aria-hidden="false"]) {
  display: block;
}
