export interface Classes {
  "tox": string;
  "tox-tinymce": string;
  "tox-tinymce-aux": string;
  "tox-tinymce-inline": string;
  "tox-editor-container": string;
  "tox-editor-header": string;
  "tox-icon--flip": string;
  "tox-editor-dock-transition": string;
  "tox-tinymce--toolbar-bottom": string;
  "tox-tinymce--toolbar-sticky-on": string;
  "tox-editor-header--empty": string;
  "tox-editor-dock-fadeout": string;
  "tox-editor-dock-fadein": string;
  "accessibility-issue__header": string;
  "accessibility-issue__subheader": string;
  "accessbility-sr-only": string;
  "accessibility-issue__description": string;
  "tox-icon": string;
  "accessibility-issue__contentID": string;
  "accessibility-issue__document": string;
  "accessibility-issue__repair": string;
  "tox-form__group": string;
  "tox-form__group--error": string;
  "tox-dialog__body-content": string;
  "accessibility-issue--info": string;
  "accessibility-issue__icon": string;
  "tox-button--naked": string;
  "tox-button--icon": string;
  "accessibility-issue--warn": string;
  "accessibility-issue--error": string;
  "accessibility-issue--success": string;
  "tox-button": string;
  "mce-codemirror": string;
  "tox-inline-codemirror": string;
  "tox-advtemplate": string;
  "tox-form__grid": string;
  "tox-force-desktop": string;
  "tox-accordion": string;
  "tox-accordion__item": string;
  "tox-accordion__item--expanded": string;
  "tox-accordion__content--expanded": string;
  "tox-accordion__content-inner": string;
  "tox-accordion__heading": string;
  "tox-accordion__header": string;
  "tox-accordion__header--disabled": string;
  "tox-accordion__header--icon-end": string;
  "tox-accordion__header-icon": string;
  "tox-accordion__header-text": string;
  "tox-accordion__content": string;
  "tox-accordion__content--collapsed": string;
  "tox-dropdown-content": string;
  "tox-button-group": string;
  "tox-accordion__model-button": string;
  "tox-selectfield": string;
  "tox-alert": string;
  "tox-alert--error": string;
  "tox-alert--warning": string;
  "tox-alert__body": string;
  "tox-alert__content": string;
  "tox-alert__message": string;
  "tox-alert__actions": string;
  "tox-anchorbar": string;
  "tox-bottom-anchorbar": string;
  "tox-bar": string;
  "tox-icon--success": string;
  "tox-icon--error": string;
  "tox-button--stretch": string;
  "tox-context-form__group": string;
  "tox-button--enabled": string;
  "tox-button--secondary": string;
  "tox-button--secondary--outline": string;
  "tox-checkbox": string;
  "tox-checkbox__input": string;
  "tox-checkbox__icons": string;
  "tox-checkbox-icon__unchecked": string;
  "tox-checkbox-icon__indeterminate": string;
  "tox-checkbox-icon__checked": string;
  "tox-checkbox--disabled": string;
  "tox-checkbox__label": string;
  "tox-collection--toolbar": string;
  "tox-collection__group": string;
  "tox-collection--grid": string;
  "tox-collection--list": string;
  "tox-collection__group-heading": string;
  "tox-collection__item": string;
  "tox-image-selector-menu": string;
  "tox-collection__item-image-selector": string;
  "tox-collection__item-icon": string;
  "tox-collection__item-image": string;
  "tox-collection__item-checkmark": string;
  "tox-image-selector__row": string;
  "tox-collection__item--active": string;
  "tox-collection__item--state-disabled": string;
  "tox-collection__item--enabled": string;
  "tox-collection--toolbar-lg": string;
  "tox-collection__item-label": string;
  "tox-collection__item-accessory": string;
  "tox-collection__item-caret": string;
  "tox-collection--horizontal": string;
  "tox-collection__item-container": string;
  "tox-collection__item-container--row": string;
  "tox-collection__item-container--align-left": string;
  "tox-collection__item-container--align-right": string;
  "tox-collection__item-container--valign-top": string;
  "tox-collection__item-container--valign-middle": string;
  "tox-collection__item-container--valign-bottom": string;
  "tox-collection__item-container--column": string;
  "tox-collection": string;
  "tox-hue-slider": string;
  "tox-rgb-form": string;
  "tox-rgba-preview": string;
  "tox-color-picker-container": string;
  "tox-sv-palette": string;
  "tox-sv-palette-spectrum": string;
  "tox-sv-palette-thumb": string;
  "tox-sv-palette-inner-thumb": string;
  "tox-hue-slider-spectrum": string;
  "tox-hue-slider-thumb": string;
  "tox-invalid": string;
  "tox-rgb-container": string;
  "tox-invalid-icon": string;
  "tox-control-wrap__status-icon-invalid": string;
  "tox-rgb-warning-note": string;
  "tox-toolbar": string;
  "tox-swatches": string;
  "tox-toolbar__primary": string;
  "tox-toolbar__overflow": string;
  "tox-swatches-menu": string;
  "tox-swatches__row": string;
  "tox-swatch": string;
  "tox-swatch--remove": string;
  "tox-swatches__picker-btn": string;
  "tox-comment": string;
  "tox-comment--selected": string;
  "tox-comment__single": string;
  "tox-comment__header": string;
  "tox-comment__date": string;
  "tox-comment__body": string;
  "tox-comment__body--expanded": string;
  "tox-comment__body--pending": string;
  "tox-comment__loading-text": string;
  "tox-comment__overlaytext": string;
  "tox-comment__expander": string;
  "tox-comment__buttonspacing": string;
  "tox-tbtn": string;
  "tox-comment__mention-btn": string;
  "tox-comment-thread": string;
  "tox-comment-thread__overlay": string;
  "tox-comment__reply": string;
  "tox-comment__edit": string;
  "tox-comment__gradient": string;
  "tox-comment__overlay": string;
  "tox-comment__busy-spinner": string;
  "tox-comment__scroll": string;
  "tox-comment--disappearing": string;
  "tox-ring-loader": string;
  "tox-rotation": string;
  "tox-user": string;
  "tox-user__avatar": string;
  "tox-user__name": string;
  "tox-dialog-wrap": string;
  "tox-dialog-wrap__backdrop": string;
  "tox-dialog-wrap__backdrop--opaque": string;
  "tox-dialog": string;
  "tox-dialog-inline": string;
  "tox-dialog__header": string;
  "tox-dialog__draghandle": string;
  "tox-dialog__dismiss": string;
  "tox-dialog__title": string;
  "tox-dialog__body": string;
  "tox-dialog__body-nav": string;
  "tox-dialog__body-nav-item": string;
  "tox-dialog__body-nav-item--active": string;
  "tox-label": string;
  "tox-label--center": string;
  "tox-label--end": string;
  "tox-dialog--width-lg": string;
  "tox-dialog--fullscreen": string;
  "tox-dialog--width-md": string;
  "tox-dialog__body-content--centered": string;
  "tox-dialog__footer": string;
  "tox-dialog__footer-start": string;
  "tox-dialog__footer-end": string;
  "tox-dialog__busy-spinner": string;
  "tox-dialog__table": string;
  "tox-dialog__iframe": string;
  "tox-dialog__iframe--opaque": string;
  "tox-navobj-bordered": string;
  "tox-navobj-bordered-focus": string;
  "tox-dialog__popups": string;
  "tox-dialog__body-iframe": string;
  "tox-navobj": string;
  "tox-dialog-dock-fadeout": string;
  "tox-dialog-dock-fadein": string;
  "tox-dialog-dock-transition": string;
  "tox-menu": string;
  "tox-dialog__disable-scroll": string;
  "tox-dropzone-container": string;
  "tox-dropzone": string;
  "tox-edit-area": string;
  "tox-edit-area__iframe": string;
  "tox-edit-focus": string;
  "tox-inline-edit-area": string;
  "tox-expandable-box": string;
  "tox-expandable-box__content": string;
  "tox-expandable-box__content--overflowing": string;
  "tox-expandable-box__content--expanded": string;
  "tox-control-wrap": string;
  "tox-control-wrap--status-invalid": string;
  "tox-control-wrap--status-unknown": string;
  "tox-control-wrap__status-icon-unknown": string;
  "tox-control-wrap--status-valid": string;
  "tox-control-wrap__status-icon-valid": string;
  "tox-control-wrap__status-icon-wrap": string;
  "tox-textfield": string;
  "tox-custom-preview": string;
  "tox-autocompleter": string;
  "tox-autocompleter-highlight": string;
  "tox-color-input": string;
  "tox-toolbar-label": string;
  "tox-form": string;
  "tox-form-group--maximize": string;
  "tox-form__group--collection": string;
  "tox-form__grid--2col": string;
  "tox-form__grid--3col": string;
  "tox-form__grid--4col": string;
  "tox-form__controls-h-stack": string;
  "tox-form__group--inline": string;
  "tox-form__group--stretched": string;
  "tox-textarea": string;
  "tox-lock": string;
  "tox-locked": string;
  "tox-lock-icon__unlock": string;
  "tox-lock-icon__lock": string;
  "tox-lock-context-form-size-input": string;
  "tox-toolbar-textfield": string;
  "tox-listboxfield": string;
  "tox-listbox--select": string;
  "tox-textarea-wrap": string;
  "tox-focusable-wrapper": string;
  "tox-custom-editor": string;
  "tox-naked-btn": string;
  "tox-textfield-size": string;
  "tox-listbox__select-label": string;
  "tox-listbox__select-chevron": string;
  "tox-fullscreen": string;
  "tox-statusbar__resize-handle": string;
  "tox-shadowhost": string;
  "tox-help__more-link": string;
  "tox-imagepreview": string;
  "tox-imagepreview__loaded": string;
  "tox-imagepreview__container": string;
  "tox-imagepreview__image": string;
  "tox-image-tools": string;
  "tox-spacer": string;
  "tox-croprect-block": string;
  "tox-croprect-handle": string;
  "tox-croprect-handle-move": string;
  "tox-croprect-handle-nw": string;
  "tox-croprect-handle-ne": string;
  "tox-croprect-handle-sw": string;
  "tox-croprect-handle-se": string;
  "tox-image-selector-loading-spinner-wrapper": string;
  "tox-image-selector-loading-spinner": string;
  "tox-image-selector": string;
  "tox-image-selector--remove": string;
  "tox-image-selector-image-wrapper": string;
  "tox-image-selector-image-img": string;
  "tox-image-selector__picker-btn": string;
  "tox-context-toolbar": string;
  "tox-toolbar__group": string;
  "tox-insert-table-picker": string;
  "tox-insert-table-picker__selected": string;
  "tox-insert-table-picker__label": string;
  "tox-mentions__card-common": string;
  "tox-mentions__card": string;
  "tox-mentions__container": string;
  "tox-mentions__avatar": string;
  "tox-mentions__username": string;
  "tox-mentions__description": string;
  "tox-menu__label": string;
  "tox-menubar": string;
  "tox-promotion": string;
  "tox-promotion-link": string;
  "tox-mbtn": string;
  "tox-mbtn--active": string;
  "tox-mbtn__select-label": string;
  "tox-mbtn__select-chevron": string;
  "tox-notification": string;
  "tox-notification--in": string;
  "tox-notification--success": string;
  "tox-notification--error": string;
  "tox-notification--warn": string;
  "tox-notification--warning": string;
  "tox-notification--info": string;
  "tox-notification__body": string;
  "tox-notification__icon": string;
  "tox-notification__dismiss": string;
  "tox-progress-bar": string;
  "tox-notification-container-dock-fadeout": string;
  "tox-notification-container-dock-fadein": string;
  "tox-notification-container-dock-transition": string;
  "tox-onboarding-overlay": string;
  "tox-onboarding-dialog": string;
  "tox-onboarding-header": string;
  "tox-onboarding-step": string;
  "tox-onboarding-step--number": string;
  "tox-onboarding-step--body": string;
  "tox-onboarding-step--body-header": string;
  "tox-onboarding-step--body-details": string;
  "tox-onboarding-step--action": string;
  "tox-onboarding-footer": string;
  "tox-promotion-dialog": string;
  "tox-promotion-dialog-plugin": string;
  "tox-promotion-dialog-plugin--body": string;
  "tox-promotion-dialog-plugin-header": string;
  "tox-promotion-dialog-plugin-details": string;
  "tox-promotion-dialog-plugin--icon": string;
  "tox-promotion-dialog--subtitle": string;
  "tox-promotion-dialog--explore": string;
  "tox-promotion-dialog--footer": string;
  "tox-promotion-button": string;
  "tox-pop": string;
  "tox-pop--resizing": string;
  "tox-pop--transition": string;
  "tox-pop__dialog": string;
  "tox-pop--inset": string;
  "tox-pop--bottom": string;
  "tox-pop--top": string;
  "tox-pop--left": string;
  "tox-pop--right": string;
  "tox-pop--align-left": string;
  "tox-pop--align-right": string;
  "tox-sidebar-wrap": string;
  "tox-sidebar": string;
  "tox-sidebar__slider": string;
  "tox-sidebar__pane-container": string;
  "tox-sidebar__pane": string;
  "tox-sidebar--sliding-closed": string;
  "tox-sidebar--sliding-open": string;
  "tox-sidebar--sliding-growing": string;
  "tox-sidebar--sliding-shrinking": string;
  "tox-sidebar-content": string;
  "tox-sidebar-content--wide": string;
  "tox-sidebar-content__header": string;
  "tox-sidebar-content__header-close-button": string;
  "tox-sidebar-content__title": string;
  "tox-floating-sidebar": string;
  "tox-floating-sidebar--open": string;
  "tox-floating-sidebar__content-wrapper": string;
  "tox-floating-sidebar__header": string;
  "tox-ai__scroll": string;
  "tox-card-list": string;
  "tox-ai": string;
  "tox-sidebar-content__loader": string;
  "tox-sidebar-content__actions": string;
  "tox-ai__complete-review": string;
  "tox-ai__review-menu-separator": string;
  "tox-ai__user-prompt": string;
  "tox-ai__user-prompt__context": string;
  "tox-tag": string;
  "tox-ai__user-prompt__text": string;
  "tox-ai__scroll--review": string;
  "tox-sidebar-content__message-text": string;
  "tox-ai__spinner": string;
  "tox-ai__response": string;
  "tox-ai__response__header": string;
  "tox-ai__response-status": string;
  "tox-ai__response-status-icon": string;
  "tox-ai__icon": string;
  "tox-ai__response-sources": string;
  "tox-ai__response-sources-header": string;
  "tox-ai__response-sources-list": string;
  "tox-ai__response-content": string;
  "tox-ai__response-streaming": string;
  "tox-ai-error": string;
  "tox-ai-error__message": string;
  "tox-ai-error__icon": string;
  "tox-ai__footer": string;
  "tox-ai__context": string;
  "tox-ai__context-more": string;
  "tox-ai__stop-generating": string;
  "tox-ai__footer-actions": string;
  "tox-ai-model-selection-button": string;
  "tox-ai__footer-note": string;
  "tox-ai__models-menu": string;
  "tox-ai__models-menu__item__description": string;
  "tox-ai__models-menu__item__description__title": string;
  "tox-ai__models-menu__item__description__content": string;
  "tox-ai__models-menu__item__description__ability": string;
  "tox-ai__models-menu__item__description__content_body": string;
  "tox-ai__models-menu__item__description__ability__enabled": string;
  "tox-ai-chat-history-list": string;
  "tox-ai-chat-history-list__title": string;
  "tox-ai-chat-history-list__item": string;
  "tox-ai-chat-history-list__item--active": string;
  "tox-ai-chat-history-list__item-edit-title": string;
  "tox-ai-chat-history-list__item-edit-actions": string;
  "tox-ai-chat-history-list__item-content": string;
  "tox-ai-chat-history-list__item-actions": string;
  "tox-ai-chat-history-list__item-content-title": string;
  "tox-ai-chat-history-list__item-content-date": string;
  "tox-sidebar-content__message": string;
  "tox-sidebar-content__message-action": string;
  "tox-ai-removed-content": string;
  "tox-ai-html-content": string;
  "tox-ai__preview-host": string;
  "tox-ai__preview-layer": string;
  "tox-ai__preview-frame-wrap": string;
  "tox-ai__iframe": string;
  "tox-ai__preview-footer": string;
  "tox-ai__preview-footer-toolbar": string;
  "tox-ai__preview-overlay": string;
  "tox-ai__preview-overlay--hidden": string;
  "tox-ai__preview-overlay--pass-through": string;
  "tox-ai__preview-overlay--dim": string;
  "tox-ai__preview-overlay--centered": string;
  "tox-ai__preview-overlay--clipped": string;
  "tox-tinymceai-previewloader": string;
  "tox-tinymceai-previewloader__content": string;
  "tox-selector": string;
  "tox-platform-touch": string;
  "tox-skeleton": string;
  "tox-skeleton__line": string;
  "wave": string;
  "tox-skeleton__circle": string;
  "tox-slider": string;
  "tox-slider__rail": string;
  "tox-slider__handle": string;
  "tox-toolbar-slider": string;
  "tox-toolbar-slider__input": string;
  "tox-source-code": string;
  "tox-spinner": string;
  "tam-bouncing-dots": string;
  "tox-ai__spinner--small": string;
  "tox-ai__spinner--circle": string;
  "tox-ai__spinner--dots": string;
  "tox-bouncing-dots": string;
  "tox-tinymceai__annotation--added": string;
  "tox-tinymceai__annotation--modified": string;
  "tox-tinymceai__annotation--removed": string;
  "tox-tinymceai__annotation--added__highlight": string;
  "tox-tinymceai__annotation--added__selected": string;
  "tox-tinymceai__annotation--modified__highlight": string;
  "tox-tinymceai__annotation--modified__selected": string;
  "tox-tinymceai__annotation--removed__highlight": string;
  "tox-tinymceai__annotation--removed__selected": string;
  "tox-tinymceai__annotation--added__hidden": string;
  "tox-tinymceai__annotation--modified__hidden": string;
  "tox-tinymceai__annotation--removed__hidden": string;
  "tox-tinymceai__annotation": string;
  "mce-pagebreak": string;
  "tox-ai__review-sidebar-container": string;
  "tox-ai__review-initializing": string;
  "tox-ai__review-description": string;
  "tox-ai__review-choose-container": string;
  "tox-ai__review-custom-input": string;
  "tox-ai__review-custom-actions": string;
  "tox-ai__review-input-container": string;
  "tox-ai__review-input-button": string;
  "tox-ai__review-dropdown-content": string;
  "tox-statusbar": string;
  "tox-statusbar__path": string;
  "tox-statusbar__right-container": string;
  "tox-statusbar__help-text": string;
  "tox-statusbar__text-container": string;
  "tox-statusbar__text-container-3-cols": string;
  "tox-statusbar__text-container--flex-end": string;
  "tox-statusbar__text-container--flex-start": string;
  "tox-statusbar__text-container--space-around": string;
  "tox-statusbar__wordcount": string;
  "tox-statusbar__path-item": string;
  "tox-statusbar__branding": string;
  "tox-statusbar__resize-cursor-default": string;
  "tox-statusbar__resize-cursor-both": string;
  "tox-tag__label": string;
  "tox-tag__close": string;
  "tox-throbber": string;
  "tox-throbber__busy-spinner": string;
  "tox-segmented-control": string;
  "tox-segmented-control__segment": string;
  "tox-segmented-control__segment--active": string;
  "tox-segmented-control--disabled": string;
  "tox-toggle": string;
  "tox-toggle__slider": string;
  "tox-tbtn__icon-wrap": string;
  "tox-tbtn--active": string;
  "tox-tbtn--enabled": string;
  "tox-tbtn--disabled": string;
  "tox-tbtn-more": string;
  "tox-tbtn--md": string;
  "tox-tbtn--lg": string;
  "tox-tbtn--return": string;
  "tox-tbtn--labeled": string;
  "tox-tbtn__vlabel": string;
  "tox-label--context-toolbar": string;
  "tox-number-input": string;
  "tox-input-wrapper": string;
  "minus": string;
  "plus": string;
  "tox-tbtn--select": string;
  "tox-tbtn--bordered": string;
  "tox-tbtn__select-label": string;
  "tox-tbtn__select-chevron": string;
  "tox-tbtn--bespoke": string;
  "tox-split-button__main": string;
  "tox-split-button__chevron": string;
  "tox-icon-text-color__color": string;
  "tox-icon-highlight-bg-color__color": string;
  "tox-toolbar-overlord": string;
  "tox-toolbar__overflow--closed": string;
  "tox-toolbar__overflow--growing": string;
  "tox-toolbar__overflow--shrinking": string;
  "tox-toolbar--scrolling": string;
  "tox-toolbar--no-divider": string;
  "tox-toolbar__group--pull-right": string;
  "tox-toolbar-input-form": string;
  "tox-tooltip": string;
  "tox-tooltip--anchor": string;
  "tox-tooltip--up": string;
  "tox-tooltip--down": string;
  "tox-tooltip--left": string;
  "tox-tooltip--right": string;
  "tox-tooltip__body": string;
  "tox-tooltip__arrow": string;
  "tox-tree": string;
  "tox-trbtn": string;
  "tox-tree__label": string;
  "tox-trbtn--disabled": string;
  "tox-trbtn--enabled": string;
  "tox-trbtn--return": string;
  "tox-trbtn--labeled": string;
  "tox-trbtn__vlabel": string;
  "tox-tree--directory": string;
  "tox-tree--directory__label": string;
  "tox-chevron": string;
  "tox-tree--directory__children--growing": string;
  "tox-tree--directory__children--shrinking": string;
  "tox-tree--directory__children--open": string;
  "tox-tree--leaf__label": string;
  "tox-icon-custom-state": string;
  "tox-tree--directory__children": string;
  "color-swatch-remove-color": string;
  "tox-view-wrap": string;
  "tox-view-wrap__slot-container": string;
  "tox-view": string;
  "tox-view__header": string;
  "tox-view__label": string;
  "tox-view__label--normal": string;
  "tox-view__label--large": string;
  "tox-view--mobile": string;
  "tox-view__toolbar": string;
  "tox-view--scrolling": string;
  "tox-view__align-right": string;
  "tox-view__toolbar__group": string;
  "tox-view__header-start": string;
  "tox-view__header-end": string;
  "tox-view__pane": string;
  "tox-view__pane_panel": string;
  "tox-well": string;
  "tox-revisionhistory__pane": string;
  "tox-revisionhistory__container": string;
  "tox-revisionhistory": string;
  "tox-revisionhistory__iframe": string;
  "tox-revisionhistory__sidebar": string;
  "tox-revisionhistory__sidebar-title": string;
  "tox-revisionhistory__revisions": string;
  "tox-revisionhistory__card": string;
  "tox-revisionhistory__card--selected": string;
  "tox-revisionhistory__card-label": string;
  "tox-revisionhistory__card-content": string;
  "tox-revisionhistory__card-info": string;
  "tox-revisionhistory__card-date-label": string;
  "tox-revisionhistory__card-author-name": string;
  "tox-revisionhistory__avatar": string;
  "tox-revisionhistory__norevision": string;
  "tox-revisionhistory__card-check-icon": string;
  "tox-card": string;
  "tox-card--selected": string;
  "tox-card--has-decision": string;
  "tox-card__header": string;
  "tox-card__body": string;
  "tox-card__actions": string;
  "tox-card__header-label": string;
  "tox-card__highlight": string;
  "tox-card__highlight--added": string;
  "tox-card__highlight--deleted": string;
  "tox-card__highlight--modified": string;
  "tox-card__actions--space-between": string;
  "tox-card__actions--flex-start": string;
  "tox-icon--badge": string;
  "tox-suggestededits__pane": string;
  "tox-suggestededits__sink": string;
  "tox-tiered-menu": string;
  "tox-suggestededits__container": string;
  "tox-suggestededits": string;
  "tox-suggestededits__content": string;
  "tox-suggestededits__model": string;
  "tox-suggestededits__iframe": string;
  "tox-suggestededits__sidebar": string;
  "tox-suggestededits__sidebar-header": string;
  "tox-suggestededits__sidebar-content": string;
  "tox-suggestededits__card": string;
  "tox-suggestededits__card--divider": string;
  "tox-suggestededits__card--single": string;
  "tox-suggestededits__card--editor": string;
  "tox-suggestededits__card--header": string;
  "tox-suggestededits__card--user": string;
  "tox-suggestededits__card--avatar": string;
  "tox-suggestededits__card--details": string;
  "tox-suggestededits__card--name": string;
  "tox-suggestededits__card--feedback-user": string;
  "tox-suggestededits__card--timestamp": string;
  "tox-suggestededits__resolution": string;
  "tox-suggestededits__resolution--accepted": string;
  "tox-suggestededits__resolution--rejected": string;
  "tox-suggestededits__card--content": string;
  "tox-suggestededits__operations": string;
  "tox-suggestededits__operations-bar": string;
  "tox-suggestededits__operations-bar--insert": string;
  "tox-suggestededits__operations-bar--modify": string;
  "tox-suggestededits__operations-bar--remove": string;
  "tox-suggestededits__operations-text": string;
  "tox-suggestededits__card--feedback": string;
  "tox-suggestededits__card--textarea": string;
  "tox-suggestededits__card--footer": string;
  "tox-suggestededits__card--buttons": string;
  "tox-suggestededits__card--review-buttons": string;
  "tox-suggestededits__card--feedback-buttons": string;
  "tox-suggestededits__card--hidden": string;
  "tox-suggestededits__card--resolved": string;
  "tox-suggestededits__card--active": string;
  "tox-dialog-loading": string;
  "tox-tab": string;
  "tox-dialog__content-js": string;
  "tox-split-button": string;
};
