<?php

/**
 * @package     Joomla.Administrator
 * @subpackage  com_admin
 *
 * @copyright   (C) 2026 Open Source Matters, Inc. <https://www.joomla.org>
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */

// phpcs:disable PSR1.Files.SideEffects
\defined('_JEXEC') or die;
// phpcs:enable PSR1.Files.SideEffects

$menu = [
    "START_HERE" => [
        "Start_Here" => "START_HERE",
        "License" => "COM_ADMIN_HELP_LICENSE",
        "Glossary" => "GLOSSARY",
        "Home_Dashboard" => "HOME_DASHBOARD",
        "Site_Global_Configuration" => "SITE_GLOBAL_CONFIGURATION",
    ],
    "CONTENT" => [
        "ARTICLES" => [
            "Articles" => "ARTICLES",
            "Articles:_Edit" => "ARTICLES:_EDIT",
            "Articles:_Categories" => "ARTICLES:_CATEGORIES",
            "Articles:_Edit_Category" => "ARTICLES:_EDIT_CATEGORY",
            "Articles:_Featured" => "ARTICLES:_FEATURED",
            "Articles:_Options" => "ARTICLES:_OPTIONS",
        ],
        "WORKFLOWS" => [
            "Workflows_List" => "WORKFLOWS_LIST",
            "Stages_List:_Basic_Workflow" => "STAGES_LIST:_BASIC_WORKFLOW",
            "Transitions_List:_Basic_Workflow" => "TRANSITIONS_LIST:_BASIC_WORKFLOW",
        ],
        "FIELDS" => [
            "Field_Groups" => "FIELD_GROUPS",
            "Field_Groups:_Edit" => "FIELD_GROUPS:_EDIT",
            "Fields" => "FIELDS",
            "Fields:_Edit" => "FIELDS:_EDIT",
        ],
        "MEDIA" => [
            "Media" => "MEDIA",
            "Media:_Options" => "MEDIA:_OPTIONS",
        ],
        "MODULES" => [
            "Modules" => "MODULES",
            "Modules:_Options" => "MODULES:_OPTIONS",
        ],
        "SITE_MODULES" => [
            "Site_Modules:_Articles" => "SITE_MODULES:_ARTICLES",
            "Site_Modules:_Articles_-_Archived" => "SITE_MODULES:_ARTICLES_-_ARCHIVED",
            "Site_Modules:_Articles_-_Latest" => "SITE_MODULES:_ARTICLES_-_LATEST",
            "Site_Modules:_Articles_-_Most_Read" => "SITE_MODULES:_ARTICLES_-_MOST_READ",
            "Site_Modules:_Articles_-_Newsflash" => "SITE_MODULES:_ARTICLES_-_NEWSFLASH",
            "Site_Modules:_Articles_-_Related" => "SITE_MODULES:_ARTICLES_-_RELATED",
            "Site_Modules:_Banners" => "SITE_MODULES:_BANNERS",
            "Site_Modules:_Breadcrumbs" => "SITE_MODULES:_BREADCRUMBS",
            "Site_Modules:_Custom" => "SITE_MODULES:_CUSTOM",
            "Site_Modules:_Feed_Display" => "SITE_MODULES:_FEED_DISPLAY",
            "Site_Modules:_Footer" => "SITE_MODULES:_FOOTER",
            "Site_Modules:_Language_Switcher" => "SITE_MODULES:_LANGUAGE_SWITCHER",
            "Site_Modules:_Login" => "SITE_MODULES:_LOGIN",
            "Site_Modules:_Menu" => "SITE_MODULES:_MENU",
            "Site_Modules:_Random_Image" => "SITE_MODULES:_RANDOM_IMAGE",
            "Site_Modules:_Smart_Search" => "SITE_MODULES:_SMART_SEARCH",
            "Site_Modules:_Statistics" => "SITE_MODULES:_STATISTICS",
            "Site_Modules:_Syndication_Feeds" => "SITE_MODULES:_SYNDICATION_FEEDS",
            "Site_Modules:_Tags_-_Popular" => "SITE_MODULES:_TAGS_-_POPULAR",
            "Site_Modules:_Tags_-_Similar" => "SITE_MODULES:_TAGS_-_SIMILAR",
            "Site_Modules:_Wrapper" => "SITE_MODULES:_WRAPPER",
        ],
        "ADMIN_MODULES" => [
            "Admin_Modules:_Action_Logs_-_Latest" => "ADMIN_MODULES:_ACTION_LOGS_-_LATEST",
            "Admin_Modules:_Administrator_Dashboard_Menu" => "ADMIN_MODULES:_ADMINISTRATOR_DASHBOARD_MENU",
            "Admin_Modules:_Administrator_Menu" => "ADMIN_MODULES:_ADMINISTRATOR_MENU",
            "Admin_Modules:_Articles_-_Latest" => "ADMIN_MODULES:_ARTICLES_-_LATEST",
            "Admin_Modules:_Custom" => "ADMIN_MODULES:_CUSTOM",
            "Admin_Modules:_Feed_Display" => "ADMIN_MODULES:_FEED_DISPLAY",
            "Admin_Modules:_Frontend_Link" => "ADMIN_MODULES:_FRONTEND_LINK",
            "Admin_Modules:_Guided_Tours" => "ADMIN_MODULES:_GUIDED_TOURS",
            "Admin_Modules:_Joomla_Version_Information" => "ADMIN_MODULES:_JOOMLA_VERSION_INFORMATION",
            "Admin_Modules:_Login_Form" => "ADMIN_MODULES:_LOGIN_FORM",
            "Admin_Modules:_Login_Support_Information" => "ADMIN_MODULES:_LOGIN_SUPPORT_INFORMATION",
            "Admin_Modules:_Messages" => "ADMIN_MODULES:_MESSAGES",
            "Admin_Modules:_Multilingual_Status" => "ADMIN_MODULES:_MULTILINGUAL_STATUS",
            "Admin_Modules:_Popular_Articles" => "ADMIN_MODULES:_POPULAR_ARTICLES",
            "Admin_Modules:_Post_Installation_Messages" => "ADMIN_MODULES:_POST_INSTALLATION_MESSAGES",
            "Admin_Modules:_Privacy_Dashboard" => "ADMIN_MODULES:_PRIVACY_DASHBOARD",
            "Admin_Modules:_Privacy_Status_Check" => "ADMIN_MODULES:_PRIVACY_STATUS_CHECK",
            "Admin_Modules:_Quick_Icons" => "ADMIN_MODULES:_QUICK_ICONS",
            "Admin_Modules:_Sample_Data" => "ADMIN_MODULES:_SAMPLE_DATA",
            "Admin_Modules:_Title" => "ADMIN_MODULES:_TITLE",
            "Admin_Modules:_Toolbar" => "ADMIN_MODULES:_TOOLBAR",
        ],
    ],
    "MENUS" => [
        "MENUS" => [
            "Menus" => "MENUS",
            "Menus:_Edit" => "MENUS:_EDIT",
            "Menus:_Items" => "MENUS:_ITEMS",
            "Menus:_Options" => "MENUS:_OPTIONS",
        ],
        "MENU_ITEMS" => [
            "Menu_Item:_Alias" => "MENU_ITEM:_ALIAS",
            "Menu_Item:_Article_Archived" => "MENU_ITEM:_ARTICLE_ARCHIVED",
            "Menu_Item:_Compact_List_of_Tagged_Items" => "MENU_ITEM:_COMPACT_LIST_OF_TAGGED_ITEMS",
            "Menu_Item:_Components_Menu_Container" => "MENU_ITEM:_COMPONENTS_MENU_CONTAINER",
            "Menu_Item:_Confirm_Request" => "MENU_ITEM:_CONFIRM_REQUEST",
            "Menu_Item:_Create_Article" => "MENU_ITEM:_CREATE_ARTICLE",
            "Menu_Item:_Create_Contact" => "MENU_ITEM:_CREATE_CONTACT",
            "Menu_Item:_Create_Request" => "MENU_ITEM:_CREATE_REQUEST",
            "Menu_Item:_Display_Template_Options" => "MENU_ITEM:_DISPLAY_TEMPLATE_OPTIONS",
            "Menu_Item:_Extend_Consent" => "MENU_ITEM:_EXTEND_CONSENT",
            "Menu_Item:_Featured_Articles" => "MENU_ITEM:_FEATURED_ARTICLES",
            "Menu_Item:_Featured_Contacts" => "MENU_ITEM:_FEATURED_CONTACTS",
            "Menu_Item:_Heading" => "MENU_ITEM:_HEADING",
            "Menu_Item:_Iframe_Wrapper" => "MENU_ITEM:_IFRAME_WRAPPER",
            "Menu_Item:_List_All_Tags" => "MENU_ITEM:_LIST_ALL_TAGS",
            "Menu_Item:_Login_Form" => "MENU_ITEM:_LOGIN_FORM",
            "Menu_Item:_Logout" => "MENU_ITEM:_LOGOUT",
            "Menu_Item:_New_Item" => "MENU_ITEM:_NEW_ITEM",
            "Menu_Item:_Password_Reset" => "MENU_ITEM:_PASSWORD_RESET",
            "Menu_Item:_Registration_Form" => "MENU_ITEM:_REGISTRATION_FORM",
            "Menu_Item:_Search" => "MENU_ITEM:_SEARCH",
            "Menu_Item:_Separator" => "MENU_ITEM:_SEPARATOR",
            "Menu_Item:_Single_Article" => "MENU_ITEM:_SINGLE_ARTICLE",
            "Menu_Item:_Single_Contact" => "MENU_ITEM:_SINGLE_CONTACT",
            "Menu_Item:_Single_News_Feed" => "MENU_ITEM:_SINGLE_NEWS_FEED",
            "Menu_Item:_Site_Configuration_Options" => "MENU_ITEM:_SITE_CONFIGURATION_OPTIONS",
            "Menu_Item:_Tagged_Items" => "MENU_ITEM:_TAGGED_ITEMS",
            "Menu_Item:_URL" => "MENU_ITEM:_URL",
        ],
    ],
    "COMPONENTS" => [
        "BANNERS" => [
            "Banners" => "BANNERS",
            "Banners:_Edit" => "BANNERS:_EDIT",
            "Banners:_Categories" => "BANNERS:_CATEGORIES",
            "Banners:_New_or_Edit_Category" => "BANNERS:_NEW_OR_EDIT_CATEGORY",
            "Banners:_Clients" => "BANNERS:_CLIENTS",
            "Banners:_New_or_Edit_Client" => "BANNERS:_NEW_OR_EDIT_CLIENT",
            "Banners:_Tracks" => "BANNERS:_TRACKS",
            "Banners:_Options" => "BANNERS:_OPTIONS",
        ],
        "CONTACTS" => [
            "Contacts" => "CONTACTS",
            "Contacts:_Edit" => "CONTACTS:_EDIT",
            "Contacts:_Categories" => "CONTACTS:_CATEGORIES",
            "Contacts:_Edit_Category" => "CONTACTS:_EDIT_CATEGORY",
            "Contacts:_Options" => "CONTACTS:_OPTIONS",
        ],
        "NEWS_FEEDS" => [
            "News_Feeds" => "NEWS_FEEDS",
            "News_Feeds:_Edit" => "NEWS_FEEDS:_EDIT",
            "News_Feeds:_Categories" => "NEWS_FEEDS:_CATEGORIES",
            "News_Feeds:_Edit_Category" => "NEWS_FEEDS:_EDIT_CATEGORY",
            "News_Feed:_Options" => "NEWS_FEED:_OPTIONS",
        ],
        "SMART_SEARCH" => [
            "Smart_Search:_Indexed_Content" => "SMART_SEARCH:_INDEXED_CONTENT",
            "Smart_Search:_Content_Maps" => "SMART_SEARCH:_CONTENT_MAPS",
            "Smart_Search:_Search_Filters" => "SMART_SEARCH:_SEARCH_FILTERS",
            "Smart_Search:_New_or_Edit_Filter" => "SMART_SEARCH:_NEW_OR_EDIT_FILTER",
            "Smart_Search:_Search_Term_Analysis" => "SMART_SEARCH:_SEARCH_TERM_ANALYSIS",
            "Smart_Search:_Options" => "SMART_SEARCH:_OPTIONS",
        ],
        "TAGS" => [
            "Tags" => "TAGS",
            "Tags:_New_or_Edit" => "TAGS:_NEW_OR_EDIT",
            "Tags:_Options" => "TAGS:_OPTIONS",
        ],
    ],
    "USERS" => [
        "Users" => "USERS",
        "Users:_Edit_Profile" => "USERS:_EDIT_PROFILE",
        "Users:_Viewing_Access_Levels" => "USERS:_VIEWING_ACCESS_LEVELS",
        "Users:_Edit_Viewing_Access_Level" => "USERS:_EDIT_VIEWING_ACCESS_LEVEL",
        "Users:_Groups" => "USERS:_GROUPS",
        "Users:_New_or_Edit_Group" => "USERS:_NEW_OR_EDIT_GROUP",
        "Permissions_for_Group" => "PERMISSIONS_FOR_GROUP",
        "Permissions_for_User" => "PERMISSIONS_FOR_USER",
        "Users:_Options" => "USERS:_OPTIONS",
    ],
    "USER_ACTIONS" => [
        "User_Actions_Log" => "USER_ACTIONS_LOG",
        "User_Actions_Log:_Options" => "USER_ACTIONS_LOG:_OPTIONS",
        "User_Notes" => "USER_NOTES",
        "User_Notes:_New_or_Edit" => "USER_NOTES:_NEW_OR_EDIT",
        "Mass_Mail_Users" => "MASS_MAIL_USERS",
        "Private_Messages" => "PRIVATE_MESSAGES",
        "Private_Messages:_Read" => "PRIVATE_MESSAGES:_READ",
        "Private_Messages:_Write" => "PRIVATE_MESSAGES:_WRITE",
        "Messages:_Options" => "MESSAGES:_OPTIONS",
    ],
    "PRIVACY" => [
        "Privacy_Dashboard" => "PRIVACY_DASHBOARD",
        "Privacy:_Consents" => "PRIVACY:_CONSENTS",
        "Privacy:_Extension_Capabilities" => "PRIVACY:_EXTENSION_CAPABILITIES",
        "Privacy:_Information_Requests" => "PRIVACY:_INFORMATION_REQUESTS",
        "Privacy:_New_Information_Request" => "PRIVACY:_NEW_INFORMATION_REQUEST",
        "Privacy:_Review_Information_Request" => "PRIVACY:_REVIEW_INFORMATION_REQUEST",
        "Privacy:_Options" => "PRIVACY:_OPTIONS",
    ],
    "SYSTEM" => [
        "EXTENSIONS" => [
            "Extensions:_Discover" => "EXTENSIONS:_DISCOVER",
            "Extensions:_Install" => "EXTENSIONS:_INSTALL",
            "Extensions:_Languages" => "EXTENSIONS:_LANGUAGES",
            "Extensions:_Manage" => "EXTENSIONS:_MANAGE",
            "Extensions:_Update" => "EXTENSIONS:_UPDATE",
            "Extensions:_Update_Sites" => "EXTENSIONS:_UPDATE_SITES",
        ],
        "TEMPLATES" => [
            "Templates:_Templates" => "TEMPLATES:_TEMPLATES",
            "Templates:_Customise" => "TEMPLATES:_CUSTOMISE",
            "Templates:_Customise_Source" => "TEMPLATES:_CUSTOMISE_SOURCE",
            "Templates:_Styles" => "TEMPLATES:_STYLES",
            "Templates:_Edit_Style" => "TEMPLATES:_EDIT_STYLE",
            "Template:_Options" => "TEMPLATE:_OPTIONS",
            "Mail_Templates" => "MAIL_TEMPLATES",
            "Mail_Template:_Edit" => "MAIL_TEMPLATE:_EDIT",
            "Mail_Templates:_Options" => "MAIL_TEMPLATES:_OPTIONS",
        ],
        "MAINTENANCE" => [
            "Information:_Database" => "INFORMATION:_DATABASE",
            "Maintenance:_Clear_Cache" => "MAINTENANCE:_CLEAR_CACHE",
            "Maintenance:_Global_Check-in" => "MAINTENANCE:_GLOBAL_CHECK-IN",
            "Cache:_Options" => "CACHE:_OPTIONS",
            "Check-in:_Options" => "CHECK-IN:_OPTIONS",
        ],
        "LANGUAGES" => [
            "Languages:_Content" => "LANGUAGES:_CONTENT",
            "Languages:_Edit_Content_Language" => "LANGUAGES:_EDIT_CONTENT_LANGUAGE",
            "Languages:_Edit_Override" => "LANGUAGES:_EDIT_OVERRIDE",
            "Languages:_Installed" => "LANGUAGES:_INSTALLED",
            "Languages:_Options" => "LANGUAGES:_OPTIONS",
            "Languages:_Overrides" => "LANGUAGES:_OVERRIDES",
            "Multilingual_Associations" => "MULTILINGUAL_ASSOCIATIONS",
            "Multilingual_Associations:_Edit" => "MULTILINGUAL_ASSOCIATIONS:_EDIT",
            "Multilingual_Associations:_Options" => "MULTILINGUAL_ASSOCIATIONS:_OPTIONS",
        ],
        "PLUGINS" => [
            "Plugins" => "PLUGINS",
            "Plugins:_Name_of_Plugin" => "PLUGINS:_NAME_OF_PLUGIN",
            "Editors" => "EDITORS",
            "Plugin:_Options" => "PLUGIN:_OPTIONS",
        ],
        "REDIRECTS" => [
            "Redirects:_Links" => "REDIRECTS:_LINKS",
            "Redirects:_New_or_Edit" => "REDIRECTS:_NEW_OR_EDIT",
            "Redirect:_Options" => "REDIRECT:_OPTIONS",
        ],
        "GUIDED_TOURS" => [
            "Guided_Tours" => "GUIDED_TOURS",
            "Guided_Tours:_New_or_Edit_Tour" => "GUIDED_TOURS:_NEW_OR_EDIT_TOUR",
            "Guided_Tours:_Steps" => "GUIDED_TOURS:_STEPS",
            "Guided_Tours:_New_or_Edit_Step" => "GUIDED_TOURS:_NEW_OR_EDIT_STEP",
            "Guided_Tours:_Options" => "GUIDED_TOURS:_OPTIONS",
        ],
        "SCHEDULED_TASKS" => [
            "Scheduled_Tasks" => "SCHEDULED_TASKS",
            "Scheduled_Tasks:_Edit" => "SCHEDULED_TASKS:_EDIT",
            "Scheduled_Tasks:_Options" => "SCHEDULED_TASKS:_OPTIONS",
        ],
        "INFORMATION" => [
            "Information:_Warnings" => "INFORMATION:_WARNINGS",
            "Post-installation_Messages_for_Joomla_CMS" => "POST-INSTALLATION_MESSAGES_FOR_JOOMLA_CMS",
            "Post-installation_Messages:_Options" => "POST-INSTALLATION_MESSAGES:_OPTIONS",
            "Site_System_Information" => "SITE_SYSTEM_INFORMATION",
        ],
        "JOOMLA_UPDATE" => [
            "Joomla_Update" => "JOOMLA_UPDATE",
            "Joomla_Update:_Options" => "JOOMLA_UPDATE:_OPTIONS",
            "Edit_Update_Site" => "EDIT_UPDATE_SITE",
            "Installer:_Options" => "INSTALLER:_OPTIONS",
        ],
    ],
];
