export interface Classes {
  "tox-tinymceai__annotation--added": string;
  "tox-tinymceai__annotation--modified": string;
  "tox-tinymceai__annotation--removed": string;
  "tox-tinymceai__annotation--added__highlight": string;
  "tox-tinymceai__annotation--added__selected": string;
  "tox-tinymceai__annotation--modified__highlight": string;
  "tox-tinymceai__annotation--modified__selected": string;
  "tox-tinymceai__annotation--removed__highlight": string;
  "tox-tinymceai__annotation--removed__selected": string;
  "tox-tinymceai__annotation--added__hidden": string;
  "tox-tinymceai__annotation--modified__hidden": string;
  "tox-tinymceai__annotation--removed__hidden": string;
  "tox-tinymceai__annotation": string;
  "mce-pagebreak": string;
  "tox-tinymceai": string;
  "tox-tinymceai__preview-body": string;
  "tox-tinymceai__preview-body--show-preview": string;
  "tox-tinymceai__annotation--preview-highlight": string;
  "tox-tinymceai__diff-focus-overlay": string;
  "tox-tinymceai__diff-focus-overlay-dim": string;
  "mce-content-body": string;
  "mce-item-anchor": string;
  "tox-comments-visible": string;
  "tox-comment": string;
  "mce-preview-object": string;
  "tox-checklist": string;
  "tox-checklist--hidden": string;
  "tox-checklist--checked": string;
  "token": string;
  "cdata": string;
  "comment": string;
  "doctype": string;
  "prolog": string;
  "punctuation": string;
  "namespace": string;
  "constant": string;
  "deleted": string;
  "property": string;
  "symbol": string;
  "tag": string;
  "boolean": string;
  "number": string;
  "attr-name": string;
  "builtin": string;
  "char": string;
  "inserted": string;
  "selector": string;
  "string": string;
  "language-css": string;
  "style": string;
  "entity": string;
  "operator": string;
  "url": string;
  "variable": string;
  "atrule": string;
  "attr-value": string;
  "class-name": string;
  "function": string;
  "keyword": string;
  "important": string;
  "regex": string;
  "bold": string;
  "italic": string;
  "mce-visual-caret": string;
  "mce-visual-caret-hidden": string;
  "mce-offscreen-selection": string;
  "tox-cursor-format-painter": string;
  "mce-footnotes": string;
  "mce-footnotes-backlink": string;
  "mce-footnote": string;
  "align-left": string;
  "align-right": string;
  "image": string;
  "align-center": string;
  "mce-shim": string;
  "mce-mergetag": string;
  "mce-mergetag-affix": string;
  "mce-object": string;
  "tiny-pageembed": string;
  "tiny-pageembed--16by9": string;
  "tiny-pageembed--1by1": string;
  "tiny-pageembed--21by9": string;
  "tiny-pageembed--4by3": string;
  "mce-visualblocks": string;
  "mce-placeholder": string;
  "mce-edit-focus": string;
  "mce-resizehandle": string;
  "mce-resize-backdrop": string;
  "mce-clonedresizable": string;
  "mce-resizetable-columns": string;
  "mce-resize-helper": string;
  "tox-rtc-user-selection": string;
  "tox-rtc-user-cursor": string;
  "tox-rtc-user-selection--1": string;
  "tox-rtc-user-selection--2": string;
  "tox-rtc-user-selection--3": string;
  "tox-rtc-user-selection--4": string;
  "tox-rtc-user-selection--5": string;
  "tox-rtc-user-selection--6": string;
  "tox-rtc-user-selection--7": string;
  "tox-rtc-user-selection--8": string;
  "tox-rtc-remote-image": string;
  "mce-match-marker": string;
  "mce-match-marker-selected": string;
  "ephox-snooker-resizer-bar": string;
  "ephox-snooker-resizer-cols": string;
  "ephox-snooker-resizer-rows": string;
  "ephox-snooker-resizer-bar-dragging": string;
  "mce-spellchecker-word": string;
  "mce-spellchecker-grammar": string;
  "tox-suggestededits__annotation--added": string;
  "tox-suggestededits__annotation--modified": string;
  "tox-suggestededits__annotation--removed": string;
  "tox-suggestededits__annotation--added__highlight": string;
  "tox-suggestededits__annotation--added__selected": string;
  "tox-suggestededits__annotation--modified__highlight": string;
  "tox-suggestededits__annotation--modified__selected": string;
  "tox-suggestededits__annotation--removed__highlight": string;
  "tox-suggestededits__annotation--removed__selected": string;
  "tox-suggestededits__annotation--added__hidden": string;
  "tox-suggestededits__annotation--modified__hidden": string;
  "tox-suggestededits__annotation--removed__hidden": string;
  "tox-suggestededits__annotation": string;
  "mce-toc": string;
  "mce-item-table": string;
  "tox-uc-loading-background": string;
  "tox-uc-loading-spinner-wrapper": string;
  "tox-uc-loading-spinner": string;
  "tox-rotation": string;
  "tox-uc-video": string;
  "tox-uploadcare-placeholder": string;
  "mce-nbsp": string;
  "mce-shy": string;
  "tox-bouncing-dots": string;
};
