<?php

/**
 * Part of the Joomla Framework Database Package
 *
 * @copyright  Copyright (C) 2005 - 2021 Open Source Matters, Inc. All rights reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE
 */

namespace Joomla\Database\Exception;

/**
 * Exception class defining an exception when attempting to change a query type
 *
 * @since  2.0.0
 */
class QueryTypeAlreadyDefinedException extends \RuntimeException
{
}
